@@ -168,40 +168,42 @@ gr_block_detail::add_item_tag(unsigned int which_output, const gr_tag_t &tag)
 }
 
 void
-gr_block_detail::remove_item_tag(unsigned int which_input, const gr_tag_t &tag)
+gr_block_detail::remove_item_tag(unsigned int which_input, const gr_tag_t &tag, long id)
 {
   if(!pmt_is_symbol(tag.key)) {
     throw pmt_wrong_type("gr_block_detail::add_item_tag key", tag.key);
   }
   else {
     // Add tag to gr_buffer's deque tags
-    d_input[which_input]->buffer()->remove_item_tag(tag);
+    d_input[which_input]->buffer()->remove_item_tag(tag, id);
   }
 }
 
-void
-gr_block_detail::get_tags_in_range(std::vector<gr_tag_t> &v,
-				   unsigned int which_input,
-				   uint64_t abs_start,
-				   uint64_t abs_end)
-{
-  // get from gr_buffer_reader's deque of tags
-  d_input[which_input]->get_tags_in_range(v, abs_start, abs_end);
-}
-
 void
 gr_block_detail::get_tags_in_range(std::vector<gr_tag_t> &v,
 				   unsigned int which_input,
 				   uint64_t abs_start,
 				   uint64_t abs_end,
-				   const pmt_t &key)
+				   long id)
+{
+  // get from gr_buffer_reader's deque of tags
+  d_input[which_input]->get_tags_in_range(v, abs_start, abs_end, id);
+}
+
+void
+gr_block_detail::get_tags_in_range(std::vector<gr_tag_t> &v,
+				   unsigned int which_input,
+				   uint64_t abs_start,
+				   uint64_t abs_end,
+				   const pmt_t &key,
+				   long id)
 {
   std::vector<gr_tag_t> found_items;
 
   v.resize(0);
 
   // get from gr_buffer_reader's deque of tags
-  d_input[which_input]->get_tags_in_range(found_items, abs_start, abs_end);
+  d_input[which_input]->get_tags_in_range(found_items, abs_start, abs_end, id);
 
   // Filter further by key name
   pmt_t itemkey;
@@ -215,7 +217,7 @@ gr_block_detail::get_tags_in_range(std::vector<gr_tag_t> &v,
 }
 
 void
-gr_block_detail::set_processor_affinity(const std::vector<unsigned int> &mask)
+gr_block_detail::set_processor_affinity(const std::vector<int> &mask)
 {
   if(threaded) {
     try {
@@ -261,6 +263,7 @@ gr_block_detail::stop_perf_counters(int noutput_items, int nproduced)
       d_var_input_buffers_full[i] = 0;
     }
     for(size_t i=0; i < d_output.size(); i++) {
+      gruel::scoped_lock guard(*d_output[i]->mutex());
       float pfull = 1.0f - static_cast<float>(d_output[i]->space_available()) /
 	static_cast<float>(d_output[i]->bufsize());
       d_avg_output_buffers_full[i] = pfull;
@@ -290,6 +293,7 @@ gr_block_detail::stop_perf_counters(int noutput_items, int nproduced)
     }
 
     for(size_t i=0; i < d_output.size(); i++) {
+      gruel::scoped_lock guard(*d_output[i]->mutex());
       float pfull = 1.0f - static_cast<float>(d_output[i]->space_available()) /
 	static_cast<float>(d_output[i]->bufsize());
 
