@@ -1,19 +1,19 @@
 /* -*- c++ -*- */
 /*
  * Copyright 2006,2007,2008,2009 Free Software Foundation, Inc.
- * 
+ *
  * This file is part of GNU Radio
- * 
+ *
  * GNU Radio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
- * 
+ *
  * GNU Radio is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with GNU Radio; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street,
@@ -48,21 +48,21 @@ private:
   friend GR_CORE_API gr_hier_block2_sptr gr_make_hier_block2(const std::string &name,
 						 gr_io_signature_sptr input_signature,
 						 gr_io_signature_sptr output_signature);
-  
+
   /*!
    * \brief Private implementation details of gr_hier_block2
    */
   gr_hier_block2_detail *d_detail;
-    
-protected: 
+
+protected:
   gr_hier_block2 (void){} //allows pure virtual interface sub-classes
   gr_hier_block2(const std::string &name,
 		 gr_io_signature_sptr input_signature,
 		 gr_io_signature_sptr output_signature);
-  
+
 public:
   virtual ~gr_hier_block2();
-  
+
   /*!
    * \brief typedef for object returned from self().
    *
@@ -90,13 +90,28 @@ public:
   /*!
    * \brief Add gr-blocks or hierarchical blocks to internal graph and wire together
    *
-   * This adds (if not done earlier by another connect) a pair of gr-blocks or 
-   * hierarchical blocks to the internal flowgraph, and wires the specified output 
+   * This adds (if not done earlier by another connect) a pair of gr-blocks or
+   * hierarchical blocks to the internal flowgraph, and wires the specified output
    * port to the specified input port.
    */
-  void connect(gr_basic_block_sptr src, int src_port, 
+  void connect(gr_basic_block_sptr src, int src_port,
 	       gr_basic_block_sptr dst, int dst_port);
 
+  /*!
+   * \brief Add gr-blocks or hierarchical blocks to internal graph and wire together
+   *
+   * This adds (if not done earlier by another connect) a pair of gr-blocks or
+   * hierarchical blocks to the internal message port subscription
+   */
+  void msg_connect(gr_basic_block_sptr src, pmt::pmt_t srcport,
+	       gr_basic_block_sptr dst, pmt::pmt_t dstport);
+  void msg_connect(gr_basic_block_sptr src, std::string srcport,
+	       gr_basic_block_sptr dst, std::string dstport);
+  void msg_disconnect(gr_basic_block_sptr src, pmt::pmt_t srcport,
+	       gr_basic_block_sptr dst, pmt::pmt_t dstport);
+  void msg_disconnect(gr_basic_block_sptr src, std::string srcport,
+	       gr_basic_block_sptr dst, std::string dstport);
+
   /*!
    * \brief Remove a gr-block or hierarchical block from the internal flowgraph.
    *
@@ -150,7 +165,40 @@ public:
   // ignored by the user.
   gr_flat_flowgraph_sptr flatten() const;
 
-  gr_hier_block2_sptr to_hier_block2(); // Needed for Python/Guile type coercion
+  gr_hier_block2_sptr to_hier_block2(); // Needed for Python type coercion
+
+  bool has_msg_port(pmt::pmt_t which_port){
+    return message_port_is_hier(which_port) || gr_basic_block::has_msg_port(which_port);
+    }   
+  
+  bool message_port_is_hier(pmt::pmt_t port_id){
+    return message_port_is_hier_in(port_id) || message_port_is_hier_out(port_id);
+    }
+  bool message_port_is_hier_in(pmt::pmt_t port_id){
+    return pmt::pmt_list_has(hier_message_ports_in, port_id);
+    }
+  bool message_port_is_hier_out(pmt::pmt_t port_id){
+    return pmt::pmt_list_has(hier_message_ports_out, port_id);
+    }
+
+  pmt::pmt_t hier_message_ports_in;
+  pmt::pmt_t hier_message_ports_out;
+
+  void message_port_register_hier_in(pmt::pmt_t port_id){
+    if(pmt::pmt_list_has(hier_message_ports_in, port_id))
+        throw std::invalid_argument("hier msg in port by this name already registered");
+    if(msg_queue.find(port_id) != msg_queue.end())
+        throw std::invalid_argument("block already has a primitive input port by this name");
+    hier_message_ports_in = pmt::pmt_list_add(hier_message_ports_in, port_id);
+    }
+  void message_port_register_hier_out(pmt::pmt_t port_id){
+    if(pmt::pmt_list_has(hier_message_ports_out, port_id))
+        throw std::invalid_argument("hier msg out port by this name already registered");
+    if(pmt::pmt_dict_has_key(message_subscribers, port_id))
+        throw std::invalid_argument("block already has a primitive output port by this name");
+    hier_message_ports_out = pmt::pmt_list_add(hier_message_ports_out, port_id);
+    }
+
 };
 
 inline gr_hier_block2_sptr cast_to_hier_block2_sptr(gr_basic_block_sptr block) {
