@@ -1,19 +1,19 @@
 /* -*- c++ -*- */
 /*
  * Copyright 2007,2008,2009 Free Software Foundation, Inc.
- * 
+ *
  * This file is part of GNU Radio
- * 
+ *
  * GNU Radio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
- * 
+ *
  * GNU Radio is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with GNU Radio; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street,
@@ -44,7 +44,7 @@ private:
 
 protected:
   gr_top_block(const std::string &name);
-    
+
 public:
   ~gr_top_block();
 
@@ -72,7 +72,7 @@ public:
    * this to adjust the maximum latency a flowgraph can exhibit.
    */
   void start(int max_noutput_items=100000);
-  
+
   /*!
    * Stop the running flowgraph.  Notifies each thread created by the
    * scheduler to shutdown, then returns to caller. Calling stop() on
@@ -118,11 +118,11 @@ public:
 
   //! Get the number of max noutput_items in the flowgraph
   int max_noutput_items();
-  
+
   //! Set the maximum number of noutput_items in the flowgraph
   void set_max_noutput_items(int nmax);
 
-  gr_top_block_sptr to_top_block(); // Needed for Python/Guile type coercion
+  gr_top_block_sptr to_top_block(); // Needed for Python type coercion
 };
 
 inline gr_top_block_sptr cast_to_top_block_sptr(gr_basic_block_sptr block) {
