@@ -53,7 +53,7 @@ static snd_pcm_format_t acceptable_formats[] = {
 static std::string
 default_device_name ()
 {
-  return gr_prefs::singleton()->get_string("audio_alsa", "default_input_device", "hw:0,0");
+  return gr_prefs::singleton()->get_string("audio_alsa", "default_input_device", "default");
 }
 
 static double
