@@ -114,7 +114,7 @@ class rx_psk_block(gr.top_block):
 
         if(options.rx_freq is not None):
             symbol_rate = options.bitrate / self._demodulator.bits_per_symbol()
-            self._source = uhd_receiver(options.args, options.bitrate,
+            self._source = uhd_receiver(options.args, symbol_rate,
                                         options.samples_per_symbol,
                                         options.rx_freq, options.rx_gain,
                                         options.spec,
