@@ -30,6 +30,7 @@ import digital_swig
 # import from local folder
 import psk
 import qam
+import qamlike
 
 tested_mod_codes = (mod_codes.NO_CODE, mod_codes.GRAY_CODE)
 
@@ -64,14 +65,19 @@ def threed_constell():
     dim = 3
     return digital_swig.constellation_calcdist(points, [], rot_sym, dim)
 
-tested_constellation_info = (
+# A list of tuples for constellation testing.  The contents of the
+# tuples are (constructor, poss_args, differential, diff_argname).
+
+# These constellations should lock on well.
+easy_constellation_info = (
     (psk.psk_constellation,
-     {'m': (2, 4, 8, 16, 32, 64),
+     {'m': (2, 4, 8, 16, ),
       'mod_code': tested_mod_codes, },
      True, None),
     (qam.qam_constellation,
-     {'constellation_points': (4, 16, 64),
-      'mod_code': tested_mod_codes, },
+     {'constellation_points': (4,),
+      'mod_code': tested_mod_codes, 
+      'large_ampls_to_corners': [False],},
      True, None),
     (digital_swig.constellation_bpsk, {}, True, None),
     (digital_swig.constellation_qpsk, {}, False, None),
@@ -81,11 +87,44 @@ tested_constellation_info = (
     (threed_constell, {}, True, None),
     )
 
-def tested_constellations():
+# These constellations don't work nicely.
+# We have a lower required error rate.
+medium_constellation_info = (
+    (psk.psk_constellation,
+     {'m': (32, 64),
+      'mod_code': tested_mod_codes, },
+     True, None),
+    (qam.qam_constellation,
+     {'constellation_points': (16 ,),
+      'mod_code': tested_mod_codes, 
+      'large_ampls_to_corners': [False, True],},
+     True, None),
+    (qamlike.qam32_holeinside_constellation,
+     {'large_ampls_to_corners': [True]},
+     True, None),
+)
+
+# These constellation are basically broken in our test
+difficult_constellation_info = (
+    (qam.qam_constellation,
+     {'constellation_points': (64,),
+      'mod_code': tested_mod_codes, 
+      'large_ampls_to_corners': [False, True],},
+     True, None),    
+)
+
+def tested_constellations(easy=True, medium=True, difficult=True):
     """
     Generator to produce (constellation, differential) tuples for testing purposes.
     """
-    for constructor, poss_args, differential, diff_argname in tested_constellation_info:
+    constellation_info = []
+    if easy:
+        constellation_info += easy_constellation_info
+    if medium:
+        constellation_info += medium_constellation_info
+    if difficult:
+        constellation_info += difficult_constellation_info
+    for constructor, poss_args, differential, diff_argname in constellation_info:
         if differential:
             diff_poss = (True, False)
         else:
@@ -158,7 +197,8 @@ class mod_demod(gr.hier_block2):
         # TX
         self.constellation = constellation
         self.differential = differential
-        self.blocks = [self]
+        import weakref
+        self.blocks = [weakref.proxy(self)]
         # We expect a stream of unpacked bits.
         # First step is to pack them.
         self.blocks.append(
@@ -199,7 +239,7 @@ class mod_demod(gr.hier_block2):
         # connect to block output
         check_index = len(self.blocks)
         self.blocks = self.blocks[:check_index]
-        self.blocks.append(self)
+        self.blocks.append(weakref.proxy(self))
 
         self.connect(*self.blocks)
 
