@@ -22,6 +22,7 @@
 
 from gnuradio import gr, gr_unittest
 import howto_swig
+from square3_ff import square3_ff
 
 class qa_howto (gr_unittest.TestCase):
 
@@ -55,5 +56,17 @@ class qa_howto (gr_unittest.TestCase):
         result_data = dst.data ()
         self.assertFloatTuplesAlmostEqual (expected_result, result_data, 6)
 
+    def test_003_square3_ff (self):
+        src_data = (-3, 4, -5.5, 2, 3)
+        expected_result = (9, 16, 30.25, 4, 9)
+        src = gr.vector_source_f (src_data)
+        sqr = square3_ff ()
+        dst = gr.vector_sink_f ()
+        self.tb.connect (src, sqr)
+        self.tb.connect (sqr, dst)
+        self.tb.run ()
+        result_data = dst.data ()
+        self.assertFloatTuplesAlmostEqual (expected_result, result_data, 6)
+
 if __name__ == '__main__':
     gr_unittest.main ()
