@@ -57,25 +57,34 @@ namespace gr {
 
     class ${blockname}_impl : public ${blockname}
     {
-    private:
+     private:
       // Nothing to declare in this block.
 
-    public:
+#if $blocktype == 'tagged_stream'
+     protected:
+      int calculate_output_stream_length(const gr_vector_int &ninput_items);
+
+#end if
+     public:
       ${blockname}_impl(${strip_default_values($arglist)});
       ~${blockname}_impl();
 
+      // Where all the action really happens
 #if $blocktype == 'general'
       void forecast (int noutput_items, gr_vector_int &ninput_items_required);
 
-      // Where all the action really happens
       int general_work(int noutput_items,
 		       gr_vector_int &ninput_items,
 		       gr_vector_const_void_star &input_items,
 		       gr_vector_void_star &output_items);
+#else if $blocktype == 'tagged_stream'
+      int work(int noutput_items,
+		       gr_vector_int &ninput_items,
+		       gr_vector_const_void_star &input_items,
+		       gr_vector_void_star &output_items);
 #else if $blocktype == 'hier'
 #silent pass
 #else
-      // Where all the action really happens
       int work(int noutput_items,
 	       gr_vector_const_void_star &input_items,
 	       gr_vector_void_star &output_items);
@@ -118,25 +127,28 @@ namespace gr {
     ${blockname}::sptr
     ${blockname}::make(${strip_default_values($arglist)})
     {
-      return gnuradio::get_initial_sptr (new ${blockname}_impl(${strip_arg_types($arglist)}));
+      return gnuradio::get_initial_sptr
+        (new ${blockname}_impl(${strip_arg_types($arglist)}));
     }
 
 #if $blocktype == 'decimator'
 #set $decimation = ', <+decimation+>'
 #else if $blocktype == 'interpolator'
 #set $decimation = ', <+interpolation+>'
+#else if $blocktype == 'tagged_stream'
+#set $decimation = ', <+len_tag_key+>'
 #else
 #set $decimation = ''
 #end if
 #if $blocktype == 'source'
 #set $inputsig = '0, 0, 0'
 #else
-#set $inputsig = '<+MIN_IN+>, <+MAX_IN+>, sizeof (<+float+>)'
+#set $inputsig = '<+MIN_IN+>, <+MAX_IN+>, sizeof(<+ITYPE+>)'
 #end if
 #if $blocktype == 'sink'
 #set $outputsig = '0, 0, 0'
 #else
-#set $outputsig = '<+MIN_IN+>, <+MAX_IN+>, sizeof (<+float+>)'
+#set $outputsig = '<+MIN_OUT+>, <+MAX_OUT+>, sizeof(<+OTYPE+>)'
 #end if
     /*
      * The private constructor
@@ -175,14 +187,36 @@ namespace gr {
                        gr_vector_const_void_star &input_items,
                        gr_vector_void_star &output_items)
     {
-        const float *in = (const float *) input_items[0];
-        float *out = (float *) output_items[0];
+        const <+ITYPE*> *in = (const <+ITYPE*> *) input_items[0];
+        <+OTYPE*> *out = (<+OTYPE*> *) output_items[0];
 
         // Do <+signal processing+>
         // Tell runtime system how many input items we consumed on
         // each input stream.
         consume_each (noutput_items);
 
+        // Tell runtime system how many output items we produced.
+        return noutput_items;
+    }
+#else if $blocktype == 'tagged_stream'
+    int
+    ${blockname}_impl::calculate_output_stream_length(const gr_vector_int &ninput_items)
+    {
+      int noutput_items = /* <+set this+> */;
+      return noutput_items ;
+    }
+
+    int
+    ${blockname}_impl::work (int noutput_items,
+                       gr_vector_int &ninput_items,
+                       gr_vector_const_void_star &input_items,
+                       gr_vector_void_star &output_items)
+    {
+        const float *in = (const float *) input_items[0];
+        float *out = (float *) output_items[0];
+
+        // Do <+signal processing+>
+
         // Tell runtime system how many output items we produced.
         return noutput_items;
     }
@@ -194,8 +228,8 @@ namespace gr {
 			  gr_vector_const_void_star &input_items,
 			  gr_vector_void_star &output_items)
     {
-        const float *in = (const float *) input_items[0];
-        float *out = (float *) output_items[0];
+        const <+ITYPE+> *in = (const <+ITYPE+> *) input_items[0];
+        <+OTYPE+> *out = (<+OTYPE+> *) output_items[0];
 
         // Do <+signal processing+>
 
@@ -230,9 +264,10 @@ namespace gr {
      */
     class ${modname.upper()}_API $blockname
     {
-        ${blockname}(${arglist});
-        ~${blockname}();
-        private:
+    public:
+      ${blockname}(${arglist});
+      ~${blockname}();
+    private:
     };
 #else
     /*!
@@ -242,18 +277,18 @@ namespace gr {
      */
     class ${modname.upper()}_API ${blockname} : virtual public $grblocktype
     {
-    public:
-       typedef boost::shared_ptr<${blockname}> sptr;
+     public:
+      typedef boost::shared_ptr<${blockname}> sptr;
 
-       /*!
-        * \\brief Return a shared_ptr to a new instance of ${modname}::${blockname}.
-        *
-        * To avoid accidental use of raw pointers, ${modname}::${blockname}'s
-        * constructor is in a private implementation
-        * class. ${modname}::${blockname}::make is the public interface for
-        * creating new instances.
-        */
-       static sptr make($arglist);
+      /*!
+       * \\brief Return a shared_ptr to a new instance of ${modname}::${blockname}.
+       *
+       * To avoid accidental use of raw pointers, ${modname}::${blockname}'s
+       * constructor is in a private implementation
+       * class. ${modname}::${blockname}::make is the public interface for
+       * creating new instances.
+       */
+      static sptr make($arglist);
     };
 #end if
 
@@ -293,12 +328,12 @@ import numpy
 #if $blocktype == 'source'
 #set $inputsig = '0, 0, 0'
 #else
-#set $inputsig = '<+MIN_IN+>, <+MAX_IN+>, gr.sizeof_<+float+>'
+#set $inputsig = '<+MIN_IN+>, <+MAX_IN+>, gr.sizeof_<+ITYPE+>'
 #end if
 #if $blocktype == 'sink'
 #set $outputsig = '0, 0, 0'
 #else
-#set $outputsig = '<+MIN_OUT+>, <+MAX_OUT+>, gr.sizeof_<+float+>'
+#set $outputsig = '<+MIN_OUT+>, <+MAX_OUT+>, gr.sizeof_<+OTYPE+>'
 #end if
 #end if
 #if $blocktype == 'interpolator'
@@ -454,7 +489,7 @@ Templates['grc_xml'] = '''<?xml version="1.0"?>
   <key>${modname}_$blockname</key>
   <category>$modname</category>
   <import>import $modname</import>
-  <make>${modname}.${blockname}(${strip_arg_types($arglist)})</make>
+  <make>${modname}.${blockname}(${strip_arg_types_grc($arglist)})</make>
   <!-- Make one 'param' node for every Parameter you want settable from the GUI.
        Sub-nodes:
        * name
@@ -473,7 +508,7 @@ Templates['grc_xml'] = '''<?xml version="1.0"?>
        * optional (set to 1 for optional inputs) -->
   <sink>
     <name>in</name>
-    <type><!-- e.g. int, real, complex, byte, short, xxx_vector, ...--></type>
+    <type><!-- e.g. int, float, complex, byte, short, xxx_vector, ...--></type>
   </sink>
 
   <!-- Make one 'source' node per output. Sub-nodes:
@@ -483,7 +518,7 @@ Templates['grc_xml'] = '''<?xml version="1.0"?>
        * optional (set to 1 for optional inputs) -->
   <source>
     <name>out</name>
-    <type><!-- e.g. int, real, complex, byte, short, xxx_vector, ...--></type>
+    <type><!-- e.g. int, float, complex, byte, short, xxx_vector, ...--></type>
   </source>
 </block>
 '''
@@ -496,12 +531,16 @@ gr_modtool help <command> -- Shows the help for a given command. '''
 
 # SWIG string
 Templates['swig_block_magic'] = """#if $version == '36'
+#if $blocktype != 'noblock'
 GR_SWIG_BLOCK_MAGIC($modname, $blockname);
+#end if
 %include "${modname}_${blockname}.h"
 #else
 %include "${modname}/${blockname}.h"
+#if $blocktype != 'noblock'
 GR_SWIG_BLOCK_MAGIC2($modname, $blockname);
 #end if
+#end if
 """
 
 ## Old stuff
@@ -542,12 +581,12 @@ ${modname}_make_${blockname} (${strip_default_values($arglist)})
 #if $blocktype == 'sink'
 #set $inputsig = '0, 0, 0'
 #else
-#set $inputsig = '<+MIN_IN+>, <+MAX_IN+>, sizeof (<+float+>)'
+#set $inputsig = '<+MIN_IN+>, <+MAX_IN+>, sizeof(<+ITYPE+>)'
 #end if
 #if $blocktype == 'source'
 #set $outputsig = '0, 0, 0'
 #else
-#set $outputsig = '<+MIN_OUT+>, <+MAX_OUT+>, sizeof (<+float+>)'
+#set $outputsig = '<+MIN_OUT+>, <+MAX_OUT+>, sizeof(<+OTYPE+>)'
 #end if
 
 /*
@@ -591,8 +630,8 @@ ${modname}_${blockname}::general_work (int noutput_items,
 				   gr_vector_const_void_star &input_items,
 				   gr_vector_void_star &output_items)
 {
-	const float *in = (const float *) input_items[0];
-	float *out = (float *) output_items[0];
+	const <+ITYPE+> *in = (const <+ITYPE+> *) input_items[0];
+	<+OTYPE+> *out = (<+OTYPE+> *) output_items[0];
 
 	// Do <+signal processing+>
 	// Tell runtime system how many input items we consumed on
@@ -610,8 +649,8 @@ ${modname}_${blockname}::work(int noutput_items,
 		  gr_vector_const_void_star &input_items,
 		  gr_vector_void_star &output_items)
 {
-	const float *in = (const float *) input_items[0];
-	float *out = (float *) output_items[0];
+	const <+ITYPE+> *in = (const <+ITYPE+> *) input_items[0];
+	<+OTYPE+> *out = (<+OTYPE+> *) output_items[0];
 
 	// Do <+signal processing+>
 
