@@ -1,15 +1,19 @@
 #include "qa_utils.h"
-extern "C" {
+
 #include <volk/volk.h>
 #include <volk/volk_prefs.h>
-}
+
+#include <ciso646>
 #include <vector>
 #include <boost/foreach.hpp>
+#include <boost/filesystem.hpp>
 #include <iostream>
 #include <fstream>
 #include <sys/stat.h>
 #include <sys/types.h>
 
+namespace fs = boost::filesystem;
+
 int main(int argc, char *argv[]) {
 
     std::vector<std::string> results;
@@ -33,6 +37,8 @@ int main(int argc, char *argv[]) {
     //VOLK_PROFILE(volk_16i_permute_and_scalar_add_a, 1e-4, 0, 2046, 10000, &results);
     //VOLK_PROFILE(volk_16i_x4_quad_max_star_16i_a, 1e-4, 0, 2046, 10000, &results);
     VOLK_PROFILE(volk_16u_byteswap_a, 0, 0, 204600, 10000, &results);
+    VOLK_PROFILE(volk_16u_byteswap_u, 0, 0, 204600, 10000, &results);
+    VOLK_PROFILE(volk_16i_32fc_dot_prod_32fc_a, 1e-4, 0, 204600, 10000, &results);
     VOLK_PROFILE(volk_32f_accumulator_s32f_a, 1e-4, 0, 204600, 10000, &results);
     VOLK_PROFILE(volk_32f_x2_add_32f_a, 1e-4, 0, 204600, 10000, &results);
     VOLK_PROFILE(volk_32f_x2_add_32f_u, 1e-4, 0, 204600, 10000, &results);
@@ -49,6 +55,7 @@ int main(int argc, char *argv[]) {
     VOLK_PROFILE(volk_32fc_deinterleave_real_32f_a, 1e-4, 0, 204600, 5000, &results);
     VOLK_PROFILE(volk_32fc_deinterleave_real_64f_a, 1e-4, 0, 204600, 1000, &results);
     VOLK_PROFILE(volk_32fc_x2_dot_prod_32fc_a, 1e-4, 0, 204600, 10000, &results);
+    VOLK_PROFILE(volk_32fc_32f_dot_prod_32fc_a, 1e-4, 0, 204600, 10000, &results);
     VOLK_PROFILE(volk_32fc_index_max_16u_a, 3, 0, 204600, 10000, &results);
     VOLK_PROFILE(volk_32fc_s32f_magnitude_16i_a, 1, 32768, 204600, 100, &results);
     VOLK_PROFILE(volk_32fc_magnitude_32f_a, 1e-4, 0, 204600, 1000, &results);
@@ -76,6 +83,7 @@ int main(int argc, char *argv[]) {
     VOLK_PROFILE(volk_32f_x2_divide_32f_a, 1e-4, 0, 204600, 2000, &results);
     VOLK_PROFILE(volk_32f_x2_dot_prod_32f_a, 1e-4, 0, 204600, 5000, &results);
     VOLK_PROFILE(volk_32f_x2_dot_prod_32f_u, 1e-4, 0, 204600, 5000, &results);
+    VOLK_PROFILE(volk_32f_x2_dot_prod_16i_a, 1e-4, 0, 204600, 5000, &results);
     //VOLK_PROFILE(volk_32f_s32f_32f_fm_detect_32f_a, 1e-4, 2046, 10000, &results);
     VOLK_PROFILE(volk_32f_index_max_16u_a, 3, 0, 204600, 5000, &results);
     VOLK_PROFILE(volk_32f_x2_s32f_interleave_16ic_a, 1, 32768, 204600, 3000, &results);
@@ -119,25 +127,20 @@ int main(int argc, char *argv[]) {
     VOLK_PROFILE(volk_32f_s32f_multiply_32f_a, 1e-4, 1.0, 204600, 10000, &results);
     VOLK_PROFILE(volk_32f_s32f_multiply_32f_u, 1e-4, 0, 204600, 1000, &results);
 
-
-    char path[256];
+    char path[1024];
     get_config_path(path);
-    std::string config_path(path);
-    std::ofstream config;
-    std::cout << "filename: " << config_path << std::endl;
-    config.open(config_path.c_str());
+    const fs::path config_path(path);
+
+    if (not fs::exists(config_path.branch_path()))
+    {
+        std::cout << "Creating " << config_path.branch_path() << "..." << std::endl;
+        fs::create_directories(config_path.branch_path());
+    }
+
+    std::cout << "Writing " << config_path << "..." << std::endl;
+    std::ofstream config(config_path.string().c_str());
     if(!config.is_open()) { //either we don't have write access or we don't have the dir yet
-        std::string dir(getenv("HOME"));
-        dir += "/.volk";
-        if(mkdir(dir.c_str(), 0777) == -1) {
-            std::cout << "Error creating directory " << dir << std::endl;
-            return -1;
-        }
-        config.open(config_path.c_str());
-        if(!config.is_open()) {
-            std::cout << "Error opening file " << config_path << std::endl;
-            return -1;
-        }
+        std::cout << "Error opening file " << config_path << std::endl;
     }
 
     config << "\
